package com.example.accounttest;

import java.util.ArrayList;

import com.tencent.libtvaccount.R;
import com.tencent.qqlivetv.accountcenter.AccountCenterProxy;
import com.tencent.qqlivetv.accountcenter.AccountConstants;
import com.tencent.qqlivetv.accountcenter.AccountUtils;
import com.tencent.qqlivetv.accountcenter.AccountCenterProxy.IAccountConnectionListener;
import com.tencent.qqlivetv.accountcenter.AccountInfo;

import android.app.Activity;
import android.content.ActivityNotFoundException;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;

public class MainActivity extends Activity implements OnClickListener{
    
    private static final String TAG = "MainActivity";
    
    private static final int REQUEST_CODE_LOGIN = 100;
    private static final String APP_NAME = "TV_TEST";
    
    private Handler mHandler;
    private AccountInfo mAccountInfo;
    
    private Button mLoginButton;
    private Button mLogoutButton;
    private Button mExpireButton;
    
    private TextView mAppnameTextView;
    private TextView mNickTextView;
    private TextView mLogoTextView;
    private TextView mOpenIdTextView;
    private TextView mAccessTokenTextView;
    private TextView mExpiredTextView;
    private TextView mThdNameTextView;
    private TextView mThdIdTextView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        
        mHandler = new Handler();
        
        mLoginButton = (Button) findViewById(R.id.login_btn);
        mLogoutButton = (Button) findViewById(R.id.logout_btn);
        mExpireButton = (Button) findViewById(R.id.expire_btn);
        
        mLoginButton.setOnClickListener(this);
        mLogoutButton.setOnClickListener(this);
        mExpireButton.setOnClickListener(this);
        
        mAppnameTextView = (TextView) findViewById(R.id.account_appname);
        mNickTextView = (TextView) findViewById(R.id.account_nick);
        mLogoTextView = (TextView) findViewById(R.id.account_logo);
        mOpenIdTextView = (TextView) findViewById(R.id.account_openid);
        mAccessTokenTextView = (TextView) findViewById(R.id.account_accesstoken);
        mExpiredTextView = (TextView) findViewById(R.id.account_expired);
        mThdNameTextView = (TextView) findViewById(R.id.account_thd_name);
        mThdIdTextView = (TextView) findViewById(R.id.account_thd_id);
        
        refreshAccountInfo();
        
        AccountCenterProxy.getInstance(this).init(new IAccountConnectionListener() {
            
            @Override
            public void onConnectionStatusChanged(boolean connected) {
                if (connected) {
                      AccountInfo info = AccountCenterProxy.getInstance(MainActivity.this).getAccountInfo(APP_NAME);
                      if (info != null) {
                          info.accessToken = AccountUtils.uninit(info.accessToken, info.appName);
                          Log.e(TAG, "info: " + info.toString());
                          mAccountInfo = info;
                          refreshAccountInfo();
                      } else {
                          Log.e(TAG, "getAccountInfo got nothing:  " + APP_NAME);
                      }
                }
            }
        });
        
//        mHandler.postDelayed(new Runnable() {
//            
//            @Override
//            public void run() {
//                ArrayList<AccountInfo> list = AccountCenterProxy.getInstance(MainActivity.this).getAccountList(3);
//                if (list == null || list.size() == 0) {
//                    Log.e(TAG, "getAccountList got nothing!");
//                } else {
//                    for (AccountInfo info : list) {
//                        info.accessToken = AccountUtils.uninit(info.accessToken, info.appName);
//                        Log.e(TAG, "list info: " + info.toString());
//                    }
//                }
//            }
//        }, 3000);
    }
    
    private void doLogin() {
        Log.i(TAG, "doLogin");
        try {
            Intent intent = new Intent();
            intent.setAction(AccountConstants.ACTION_LOGIN);
            intent.putExtra(AccountConstants.INTENT_PARAM_KEY_APP_NAME, APP_NAME);
            intent.putExtra(AccountConstants.INTENT_PARAM_KEY_GUID, "11111111112222222222333333333344");
            MainActivity.this
                    .startActivityForResult(intent, REQUEST_CODE_LOGIN);
        } catch (ActivityNotFoundException e) {
            Log.e(TAG, "startActivityForResult:  " + e);
        }
    }
    
    private void doLogout() {
        Log.i(TAG, "doLogout");
        AccountCenterProxy.getInstance(this).logout(APP_NAME);
        mAccountInfo = null;
        refreshAccountInfo();
    }
    
    private void doExpired() {
        Log.i(TAG, "doExpired");
        if (mAccountInfo != null) {
            AccountCenterProxy.getInstance(this).setExpired(APP_NAME, mAccountInfo.openId, mAccountInfo.md5);
            mAccountInfo.isExpired = true;
            refreshAccountInfo();
        }
    }
    
    private void refreshAccountInfo() {
        mHandler.post(new Runnable() {
            
            @Override
            public void run() {
                mAppnameTextView.setText("应用名称：" + APP_NAME);
                mNickTextView.setText("帐号昵称：" + (mAccountInfo != null ? mAccountInfo.nick : ""));
                mLogoTextView.setText("帐号头像：" + (mAccountInfo != null ? mAccountInfo.logo : ""));
                mOpenIdTextView.setText("OpenId：" + (mAccountInfo != null ? mAccountInfo.openId : ""));
                mAccessTokenTextView.setText("AccessToken：" + (mAccountInfo != null ? mAccountInfo.accessToken : ""));
                mExpiredTextView.setText("是否过期：" + (mAccountInfo != null ? (mAccountInfo.isExpired ? "是" : "否") : ""));
                mThdNameTextView.setText("第三方帐号名称：" + (mAccountInfo != null ? mAccountInfo.thirdAccountName : ""));
                mThdIdTextView.setText("第三方帐号ID：" + (mAccountInfo != null ? mAccountInfo.thirdAccountId : ""));
                
                mLoginButton.setEnabled(mAccountInfo == null || mAccountInfo.isExpired);
                mLogoutButton.setEnabled(mAccountInfo != null && !mAccountInfo.isExpired);
                mExpireButton.setEnabled(mAccountInfo != null && !mAccountInfo.isExpired);
            }
        });
    }
    
    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        
        if (resultCode == RESULT_OK) {
            switch (requestCode) {
            case REQUEST_CODE_LOGIN:
                if (data != null) {
                    AccountInfo info = data.getParcelableExtra(AccountConstants.INTENT_PARAM_KEY_ACCOUNT_INFO);
                    if (info != null) {
                        Log.e(TAG, "onActivityResult info: " + info.toString());
                        mAccountInfo = info;
                        refreshAccountInfo();
                    }
                }
                break;
                
            default:
                break;
            }
        }
    }

    @Override
    protected void onResume() {
        super.onResume();
    }

    @Override
    protected void onDestroy() {
        Log.i(TAG, "onDestroy");
        AccountCenterProxy.getInstance(this).destory();
        super.onDestroy();
    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
        case R.id.login_btn:
            doLogin();
            break;
            
        case R.id.logout_btn:
            doLogout();
            break;
            
        case R.id.expire_btn:
            doExpired();
            break;
        }
    }

}
