package com.tencent.qqlivetv.accountcenter;

import java.util.ArrayList;
import java.util.List;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.content.pm.ResolveInfo;
import android.text.TextUtils;
import android.util.Log;

public class AccountUtils {
    
    private static final String TAG = "AccountUtils";
    
    private static final String JSON_KEY_LIST = "list";
    private static final String JSON_KEY_APP_NAME = "app_name";
    private static final String JSON_KEY_NICK = "nick";
    private static final String JSON_KEY_LOGO = "logo";
    private static final String JSON_KEY_OPEN_ID = "open_id";
    private static final String JSON_KEY_ACCESS_TOKEN = "access_token";
    private static final String JSON_KEY_EXPIRED = "expired";
    private static final String JSON_KEY_THD_ACCOUNT_NAME = "thd_account_name";
    private static final String JSON_KEY_THD_ACCOUNT_ID = "thd_account_id";
    private static final String JSON_KEY_MD5 = "md5";
    private static final String JSON_KEY_TIMESTAMP = "timestamp";
    
    static {
        try {
            System.loadLibrary("tvaccount");
        } catch (Exception e) {
            e.printStackTrace();
        } catch (Error e) {
            e.printStackTrace();
        }
    }
    
    public static ArrayList<AccountInfo> jsonToList(String json) {
        ArrayList<AccountInfo> list = null;
        
        if (!TextUtils.isEmpty(json)) {
            try {
                JSONObject jsonObject = new JSONObject(json);
                JSONArray array = jsonObject.optJSONArray(JSON_KEY_LIST);
                if (array != null) {
                    int size = array.length();
                    list = new ArrayList<AccountInfo>(size);
                    for (int i = 0; i < size; ++i) {
                        JSONObject accountJson = array.getJSONObject(i);
                        if (accountJson != null) {
                            AccountInfo info = new AccountInfo();
                            info.appName = accountJson.optString(JSON_KEY_APP_NAME);
                            info.nick = accountJson.optString(JSON_KEY_NICK);
                            info.logo = accountJson.optString(JSON_KEY_LOGO);
                            info.openId = accountJson.optString(JSON_KEY_OPEN_ID);
                            info.accessToken = accountJson.optString(JSON_KEY_ACCESS_TOKEN);
                            info.isExpired = accountJson.optBoolean(JSON_KEY_EXPIRED);
                            info.thirdAccountName = accountJson.optString(JSON_KEY_THD_ACCOUNT_NAME);
                            info.thirdAccountId = accountJson.optString(JSON_KEY_THD_ACCOUNT_ID);
                            info.timestamp = accountJson.optLong(JSON_KEY_TIMESTAMP);
                            info.md5 = accountJson.optString(JSON_KEY_MD5);
                            list.add(info);
                        }
                    }
                }
            } catch (JSONException e) {
                Log.e(TAG, "parse TCP config catch JOSNException: " + e.toString());
            }
        }
        
        Log.i(TAG, "jsonToList: size = " + (list != null ? list.size() : 0));
        
        return list;
    }
    
    public static String listTojson(ArrayList<AccountInfo> list) {
        String json = "";
        
        if (list != null && list.size() > 0) {
            JSONObject jsonObject = new JSONObject();
            JSONArray array = new JSONArray();
            for (AccountInfo info : list) {
                JSONObject jsonAccount = new JSONObject();
                boolean hasException = false;
                try {
                    jsonAccount.put(JSON_KEY_APP_NAME, info.appName);
                    jsonAccount.put(JSON_KEY_NICK, info.nick);
                    jsonAccount.put(JSON_KEY_LOGO, info.logo);
                    jsonAccount.put(JSON_KEY_OPEN_ID, info.openId);
                    jsonAccount.put(JSON_KEY_ACCESS_TOKEN, info.accessToken);
                    jsonAccount.put(JSON_KEY_EXPIRED, info.isExpired);
                    jsonAccount.put(JSON_KEY_THD_ACCOUNT_NAME, info.thirdAccountName);
                    jsonAccount.put(JSON_KEY_THD_ACCOUNT_ID, info.thirdAccountId);
                    jsonAccount.put(JSON_KEY_MD5, info.md5);
                    jsonAccount.put(JSON_KEY_TIMESTAMP, info.timestamp);
                } catch (JSONException e) {
                    e.printStackTrace();
                    hasException = true;
                }
                
                if (!hasException) {
                    array.put(jsonAccount);
                }
            }
            try {
                jsonObject.put(JSON_KEY_LIST, array);
                json = jsonObject.toString();
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
        
        Log.i(TAG, "listTojson: json = " + json);
        return json;
    }
    
    /**
     * 获取能启动intent的app信息
     * 
     * @param context
     * @param intent
     * @return
     */
    private static List<ResolveInfo> getAppsForIntent(Context context, Intent intent) {
        PackageManager packageManager = context.getPackageManager();
        // 属性
        List<ResolveInfo> resolveInfo = packageManager.queryIntentActivities(intent, PackageManager.MATCH_DEFAULT_ONLY);

        for (ResolveInfo info : resolveInfo) {
            Log.i(TAG, "resolve info:" + info.activityInfo.packageName);
        }

        return resolveInfo;
    }
    
    /**
     * 是否有启动intent的app
     * 
     * @param context
     * @param intent
     * @return
     */
    private static boolean hasAppsStartIntent(Context context, Intent intent) {
        List<ResolveInfo> appInfos = getAppsForIntent(context, intent);
        return appInfos != null && appInfos.size() > 0;
    }
    
    /**
     * 帐号中心是否存在
     * @param context
     * @return
     */
    public static boolean hasAccountCenter(Context context) {
        boolean result = false;
        
        if (context != null) {
            Intent intentCheck = new Intent();
            intentCheck.setAction(AccountConstants.ACTION_LOGIN);
            result = hasAppsStartIntent(context, intentCheck);
        }
        
        return result;
    }
    
    public native static String init(String token, String appName);
    public native static String uninit(String token, String appName);
}